@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -39,7 +39,6 @@
 #include <dbus/dbus-glib.h>
 
 #include "gpm-brightness-lcd.h"
-#include "gpm-conf.h"
 #include "gpm-common.h"
 #include "gpm-debug.h"
 #include "gpm-hal.h"
@@ -60,7 +59,6 @@ struct GpmBrightnessLcdPrivate
 	guint			 level_std_hw;
 	guint			 levels;
 	gchar			*udi;
-	GpmConf			*conf;
 	GpmProxy		*gproxy;
 	GpmHal			*hal;
 };
@@ -85,10 +83,10 @@ static gboolean
 gpm_brightness_lcd_get_hw (GpmBrightnessLcd *brightness,
 			   guint	    *brightness_level_hw)
 {
-	GError     *error = NULL;
-	gboolean    ret;
+	GError *error = NULL;
+	gboolean ret;
 	DBusGProxy *proxy;
-	int         level;
+	int level;
 
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_LCD (brightness), FALSE);
@@ -101,8 +99,9 @@ gpm_brightness_lcd_get_hw (GpmBrightnessLcd *brightness,
 
 	ret = dbus_g_proxy_call (proxy, "GetBrightness", &error,
 				 G_TYPE_INVALID,
-				 G_TYPE_INT, &level,
+				 G_TYPE_UINT, &level,
 				 G_TYPE_INVALID);
+
 	if (brightness_level_hw != NULL) {
 		*brightness_level_hw = (guint)level;
 	}
@@ -116,6 +115,8 @@ gpm_brightness_lcd_get_hw (GpmBrightnessLcd *brightness,
 		gpm_warning ("GetBrightness failed!");
 		return FALSE;
 	}
+	gpm_debug ("GetBrightness returned level: %i", level);
+
 	return TRUE;
 }
 
@@ -135,6 +136,7 @@ gpm_brightness_lcd_set_hw (GpmBrightnessLcd *brightness,
 	GError *error = NULL;
 	gboolean ret;
 	DBusGProxy *proxy;
+	gint retval;
 
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_LCD (brightness), FALSE);
@@ -157,7 +159,10 @@ gpm_brightness_lcd_set_hw (GpmBrightnessLcd *brightness,
 	ret = dbus_g_proxy_call (proxy, "SetBrightness", &error,
 				 G_TYPE_INT, (int)brightness_level_hw,
 				 G_TYPE_INVALID,
+				 G_TYPE_UINT, &retval,
 				 G_TYPE_INVALID);
+	/* retval is ignored, the HAL API is broken... */
+
 	if (error) {
 		gpm_debug ("ERROR: %s", error->message);
 		g_error_free (error);
@@ -317,13 +322,12 @@ gpm_brightness_lcd_set_std (GpmBrightnessLcd *brightness,
 	g_return_val_if_fail (brightness != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BRIGHTNESS_LCD (brightness), FALSE);
 
-	level_hw = gpm_percent_to_discrete (brightness_level,
-						     brightness->priv->levels);
+	level_hw = gpm_percent_to_discrete (brightness_level, brightness->priv->levels);
 	brightness->priv->level_std_hw = level_hw;
 
 	/* if in this state, then update */
 	if (brightness->priv->is_dimmed == FALSE) {
-		gpm_brightness_lcd_dim_hw (brightness, brightness->priv->level_std_hw);
+		gpm_brightness_lcd_dim_hw (brightness, level_hw);
 	}
 	return TRUE;
 }
@@ -501,9 +505,6 @@ gpm_brightness_lcd_finalize (GObject *object)
 	if (brightness->priv->hal != NULL) {
 		g_object_unref (brightness->priv->hal);
 	}
-	if (brightness->priv->conf != NULL) {
-		g_object_unref (brightness->priv->conf);
-	}
 
 	g_return_if_fail (brightness->priv != NULL);
 	G_OBJECT_CLASS (gpm_brightness_lcd_parent_class)->finalize (object);
@@ -548,19 +549,13 @@ gpm_brightness_lcd_init (GpmBrightnessLcd *brightness)
 	gchar **names;
 	gchar *manufacturer_string = NULL;
 	gboolean res;
-	guint value;
 
 	brightness->priv = GPM_BRIGHTNESS_LCD_GET_PRIVATE (brightness);
 
 	brightness->priv->hal = gpm_hal_new ();
-	brightness->priv->conf = gpm_conf_new ();
-
-	/* set the default dim */
-	gpm_conf_get_uint (brightness->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
-	gpm_brightness_lcd_set_dim (brightness, value);
 
 	/* save udi of lcd adapter */
-	gpm_hal_device_find_capability (brightness->priv->hal, "laptop_panel", &names);
+	gpm_hal_device_find_capability (brightness->priv->hal, "laptop_panel", &names, NULL);
 	if (names == NULL || names[0] == NULL) {
 		gpm_warning ("No devices of capability laptop_panel");
 		return;
@@ -578,7 +573,7 @@ gpm_brightness_lcd_init (GpmBrightnessLcd *brightness)
 	 * https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=173382 */
 	gpm_hal_device_get_string (brightness->priv->hal, HAL_ROOT_COMPUTER,
 				   "smbios.system.manufacturer",
-				   &manufacturer_string);
+				   &manufacturer_string, NULL);
 	if (manufacturer_string) {
 		/* FIXME: This should be a HAL property */
 		if (strcmp (manufacturer_string, "IBM") == 0) {
@@ -592,7 +587,7 @@ gpm_brightness_lcd_init (GpmBrightnessLcd *brightness)
 	   feedback loop. */
 	res = gpm_hal_device_get_bool (brightness->priv->hal, brightness->priv->udi,
 				       "laptop_panel.brightness_in_hardware",
-				       &brightness->priv->does_own_updates);
+				       &brightness->priv->does_own_updates, NULL);
 	/* This key does not exist on normal machines */
 	if (!res) {
 		brightness->priv->does_own_updates = FALSE;
@@ -607,20 +602,22 @@ gpm_brightness_lcd_init (GpmBrightnessLcd *brightness)
 			  HAL_DBUS_INTERFACE_LAPTOP_PANEL);
 
 	/* get levels that the adapter supports -- this does not change ever */
-	gpm_hal_device_get_uint (brightness->priv->hal,
-				 brightness->priv->udi,
-				 "laptop_panel.num_levels",
-				 &brightness->priv->levels);
+	gpm_hal_device_get_uint (brightness->priv->hal, brightness->priv->udi,
+				 "laptop_panel.num_levels", &brightness->priv->levels, NULL);
+	gpm_debug ("Laptop panel levels: %i", brightness->priv->levels);
+	if (brightness->priv->levels == 0 || brightness->priv->levels > 256) {
+		gpm_warning ("Laptop panel levels are invalid!");
+	}
 
 	/* this changes under our feet */
 	gpm_brightness_lcd_get_hw (brightness, &brightness->priv->current_hw);
+	gpm_debug ("current hw brightness: %i", brightness->priv->current_hw);
 
 	/* set to known value */
-	brightness->priv->level_dim_hw = 1;
-	brightness->priv->level_std_hw = 1;
+	brightness->priv->level_dim_hw = 0;
+	brightness->priv->level_std_hw = 0;
 
-	gpm_debug ("Starting: (%i of %i)",
-		   brightness->priv->current_hw,
+	gpm_debug ("Starting: (%i of %i)", brightness->priv->current_hw,
 		   brightness->priv->levels - 1);
 }
 
@@ -639,7 +636,7 @@ gpm_brightness_lcd_has_hw (void)
 
 	/* okay, as singleton - so we don't allocate more memory */
 	hal = gpm_hal_new ();
-	gpm_hal_device_find_capability (hal, "laptop_panel", &names);
+	gpm_hal_device_find_capability (hal, "laptop_panel", &names, NULL);
 
 	/* nothing found */
 	if (names == NULL || names[0] == NULL) {
