@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -70,7 +70,7 @@ struct GpmInfoPrivate
 	GpmInfoData		*rate_data;
 	GpmInfoData		*time_data;
 	GpmInfoData		*percentage_data;
-	GpmInfoData		*voltage;
+	GpmInfoData		*voltage_data;
 
 	time_t			 start_time;
 	gboolean		 is_laptop;
@@ -147,20 +147,34 @@ device_list_to_strv (GList *list)
  * Return value: TRUE for success.
  **/
 gboolean
-gpm_statistics_get_types (GpmInfo  *info,
-			  gchar  ***types,
-			  GError  **error)
+gpm_statistics_get_data_types (GpmInfo  *info,
+			       gchar  ***types,
+			       GError  **error)
 {
 	GList *list = NULL;
+	GList *data;
 
 	g_return_val_if_fail (info != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_INFO (info), FALSE);
 	g_return_val_if_fail (types != NULL, FALSE);
 
-	list = g_list_append (list, "charge");
-	list = g_list_append (list, "power");
-	list = g_list_append (list, "time");
-	list = g_list_append (list, "voltage");
+	/* only return the type if we have sufficient data */
+	data = gpm_info_data_get_list (info->priv->rate_data);
+	if (g_list_length (data) > 2) {
+		list = g_list_append (list, "power");
+	}
+	data = gpm_info_data_get_list (info->priv->time_data);
+	if (g_list_length (data) > 2) {
+		list = g_list_append (list, "time");
+	}
+	data = gpm_info_data_get_list (info->priv->percentage_data);
+	if (g_list_length (data) > 2) {
+		list = g_list_append (list, "charge");
+	}
+	data = gpm_info_data_get_list (info->priv->voltage_data);
+	if (g_list_length (data) > 2) {
+		list = g_list_append (list, "voltage");
+	}
 
 	*types = device_list_to_strv (list);
 
@@ -169,7 +183,7 @@ gpm_statistics_get_types (GpmInfo  *info,
 }
 
 /**
- * gpm_statistics_get_axis_type:
+ * gpm_statistics_get_axis_types:
  * @info: This class instance
  * @type: The graph type, e.g. "charge", "power", "time", etc.
  * @axis_type_x: The axis type, only "percentage", "power" or "time"
@@ -178,11 +192,11 @@ gpm_statistics_get_types (GpmInfo  *info,
  * Return value: TRUE for success, if FALSE then error set
  **/
 gboolean
-gpm_statistics_get_axis_type (GpmInfo *info,
-			      gchar   *type,
-			      gchar  **axis_type_x,
-			      gchar  **axis_type_y,
-			      GError **error)
+gpm_statistics_get_axis_types (GpmInfo *info,
+			       gchar   *type,
+			       gchar  **axis_type_x,
+			       gchar  **axis_type_y,
+			       GError **error)
 {
 	g_return_val_if_fail (info != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_INFO (info), FALSE);
@@ -239,7 +253,6 @@ gpm_statistics_get_event_log (GpmInfo    *info,
 	g_return_val_if_fail (GPM_IS_INFO (info), FALSE);
 	g_return_val_if_fail (array != NULL, FALSE);
 
-	gpm_debug ("seconds=%i", seconds);
 	events = gpm_info_data_get_list (info->priv->events);
 	*array = g_ptr_array_sized_new (g_list_length (events));
 
@@ -252,6 +265,8 @@ gpm_statistics_get_event_log (GpmInfo    *info,
 		g_ptr_array_add (*array, g_value_get_boxed (value));
 		g_free (value);
 	}
+	g_list_free (events);
+
 	return TRUE;
 }
 
@@ -279,6 +294,14 @@ gpm_statistics_get_data (GpmInfo     *info,
 	g_return_val_if_fail (type != NULL, FALSE);
 	g_return_val_if_fail (array != NULL, FALSE);
 
+	if (info->priv->is_laptop == FALSE) {
+		gpm_warning ("Data not available as not a laptop");
+		*error = g_error_new (gpm_info_error_quark (),
+				      GPM_INFO_ERROR_DATA_NOT_AVAILABLE,
+				      "Data not available as not a laptop");
+		return FALSE;
+	}
+
 	if (strcmp (type, "power") == 0) {
 		events = gpm_info_data_get_list (info->priv->rate_data);
 	} else if (strcmp (type, "time") == 0) {
@@ -286,7 +309,7 @@ gpm_statistics_get_data (GpmInfo     *info,
 	} else if (strcmp (type, "charge") == 0) {
 		events = gpm_info_data_get_list (info->priv->percentage_data);
 	} else if (strcmp (type, "voltage") == 0) {
-		events = gpm_info_data_get_list (info->priv->voltage);
+		events = gpm_info_data_get_list (info->priv->voltage_data);
 	} else {
 		gpm_warning ("Data type %s not known!", type);
 		*error = g_error_new (gpm_info_error_quark (),
@@ -303,8 +326,7 @@ gpm_statistics_get_data (GpmInfo     *info,
 		return FALSE;
 	}		
 
-	/* TODO! */
-	gpm_debug ("seconds=%i", seconds);
+	/* TODO: process seconds */
 	*array = g_ptr_array_sized_new (g_list_length (events));
 
 	for (l=events; l != NULL; l=l->next) {
@@ -316,6 +338,8 @@ gpm_statistics_get_data (GpmInfo     *info,
 		g_ptr_array_add (*array, g_value_get_boxed (value));
 		g_free (value);
 	}
+
+	g_list_free (events);
 	return TRUE;
 }
 
@@ -361,7 +385,7 @@ gpm_info_log_do_poll (gpointer data)
 				      GPM_POWER_KIND_PRIMARY,
 				      &battery_status);
 
-	if (info->priv->is_laptop) {
+	if (info->priv->is_laptop == TRUE) {
 		/* work out seconds elapsed */
 		value_x = time (NULL) - (info->priv->start_time + GPM_INFO_DATA_POLL);
 
@@ -386,12 +410,12 @@ gpm_info_log_do_poll (gpointer data)
 		}
 
 		/* sanity check to less than 10 hours */
-		if (battery_status.charge_rate_raw < 10*60*60) {
+		if (battery_status.remaining_time < 10*60*60) {
 			gpm_info_data_add (info->priv->time_data,
 					   value_x,
 					   battery_status.remaining_time, colour);
 		}
-		gpm_info_data_add (info->priv->voltage,
+		gpm_info_data_add (info->priv->voltage_data,
 				   value_x,
 				   battery_status.voltage, colour);
 	}
@@ -564,9 +588,6 @@ gpm_info_init (GpmInfo *info)
 	g_signal_connect (info->priv->control, "sleep-failure",
 			  G_CALLBACK (control_sleep_failure_cb), info);
 
-	/* set up the timer callback so we can log data */
-	g_timeout_add (GPM_INFO_DATA_POLL * 1000, gpm_info_log_do_poll, info);
-
 	/* find out if we should log and display the extra graphs */
 	info->priv->is_laptop = gpm_hal_is_laptop (info->priv->hal);
 
@@ -595,19 +616,23 @@ gpm_info_init (GpmInfo *info)
 
 	/* set to a blank list */
 	info->priv->events = gpm_info_data_new ();
-	if (info->priv->is_laptop) {
+	if (info->priv->is_laptop == TRUE) {
 		info->priv->percentage_data = gpm_info_data_new ();
 		info->priv->rate_data = gpm_info_data_new ();
 		info->priv->time_data = gpm_info_data_new ();
-		info->priv->voltage = gpm_info_data_new ();
+		info->priv->voltage_data = gpm_info_data_new ();
+
+		/* set up the timer callback so we can log data */
+		g_timeout_add (GPM_INFO_DATA_POLL * 1000, gpm_info_log_do_poll, info);
+
 	} else {
 		info->priv->percentage_data = NULL;
 		info->priv->rate_data = NULL;
 		info->priv->time_data = NULL;
-		info->priv->voltage = NULL;
+		info->priv->voltage_data = NULL;
 	}
 
-	if (info->priv->is_laptop) {
+	if (info->priv->is_laptop == TRUE) {
 		/* get the maximum x-axis size from gconf */
 		GpmConf *conf = gpm_conf_new ();
 		guint max_time;
@@ -618,7 +643,7 @@ gpm_info_init (GpmInfo *info)
 		gpm_info_data_set_max_time (info->priv->percentage_data, max_time);
 		gpm_info_data_set_max_time (info->priv->rate_data, max_time);
 		gpm_info_data_set_max_time (info->priv->time_data, max_time);
-		gpm_info_data_set_max_time (info->priv->voltage, max_time);
+		gpm_info_data_set_max_time (info->priv->voltage_data, max_time);
 	}
 }
 
@@ -645,8 +670,8 @@ gpm_info_finalize (GObject *object)
 	if (info->priv->time_data) {
 		g_object_unref (info->priv->time_data);
 	}
-	if (info->priv->voltage) {
-		g_object_unref (info->priv->voltage);
+	if (info->priv->voltage_data) {
+		g_object_unref (info->priv->voltage_data);
 	}
 	if (info->priv->ac_adapter != NULL) {
 		g_object_unref (info->priv->ac_adapter);
