@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Taken in part from:
  *  - lshal   (C) 2003 David Zeuthen, <david@fubar.dk>
@@ -40,7 +40,7 @@
 #include "gpm-debug.h"
 
 #include "gpm-manager.h"
-#include "gpm-interface-manager.h"
+#include "dbus/gpm-dbus-manager.h"
 
 static void gpm_exit (GpmManager *manager);
 
@@ -176,7 +176,6 @@ main (int argc, char *argv[])
 	master = gnome_master_client ();
 	flags = gnome_client_get_flags (master);
 
-
 	if (flags & GNOME_CLIENT_IS_CONNECTED) {
 		/* We'll disable this as users are getting constant crashes */
 		/* gnome_client_set_restart_style (master, GNOME_RESTART_IMMEDIATELY);*/
@@ -198,6 +197,13 @@ main (int argc, char *argv[])
 		}
 	}
 
+	/* we need to daemonize before we get a system connection to fix #366057 */
+	if (! no_daemon && daemon (0, 0)) {
+		gpm_critical_error ("Could not daemonize: %s", g_strerror (errno));
+	}
+
+	gpm_debug ("GNOME %s %s", GPM_NAME, VERSION);
+
 	/* check dbus connections, exit if not valid */
 	system_connection = dbus_g_bus_get (DBUS_BUS_SYSTEM, &error);
 	if (error) {
@@ -227,10 +233,6 @@ main (int argc, char *argv[])
 		gpm_critical_error ("Cannot continue without stock icons");
 	}
 
-	if (! no_daemon && daemon (0, 0)) {
-		gpm_critical_error ("Could not daemonize: %s", g_strerror (errno));
-	}
-
 	manager = gpm_manager_new ();
 
 	if (!gpm_object_register (session_connection, G_OBJECT (manager))) {
@@ -238,8 +240,6 @@ main (int argc, char *argv[])
 		return 0;
 	}
 
-	dbus_g_object_type_install_info (GPM_TYPE_MANAGER, &dbus_glib_gpm_manager_object_info);
-
 	loop = g_main_loop_new (NULL, FALSE);
 
 	/* Only timeout and close the mainloop if we have specified it
@@ -255,7 +255,10 @@ main (int argc, char *argv[])
 
 	g_object_unref (manager);
 	g_object_unref (program);
+	/*
+	In uncommented, valgrind reports an invalid read
 	g_option_context_free (context);
+	*/
 
 	return 0;
 }
