@@ -2,7 +2,7 @@
  *
  * Copyright (C) 2005 Jaap Haitsma <jaap@haitsma.org>
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -31,8 +31,8 @@
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-help.h>
 
-#if HAVE_LIBGUNIQUEAPP
-#include <libguniqueapp/guniqueapp.h>
+#if HAVE_GTKUNIQUE
+#include <gtkunique/gtkunique.h>
 #endif
 
 #include "gpm-prefs.h"
@@ -71,20 +71,24 @@ gpm_prefs_close_cb (GpmPrefs *prefs)
 	exit (0);
 }
 
-#if HAVE_LIBGUNIQUEAPP
+#if HAVE_GTKUNIQUE
 /**
- * guniqueapp_command_cb:
+ * gtkuniqueapp_command_cb:
  **/
 static void
-guniqueapp_command_cb (GUniqueApp       *app,
-		       GUniqueAppCommand command,
-		       gchar            *data,
-		       gchar            *startup_id,
-		       guint             workspace,
-		       gpointer          user_data)
+gtkuniqueapp_command_cb (GtkUniqueApp    *app,
+		         GtkUniqueCommand command,
+		         const gchar     *data,
+		         const gchar     *startup_id,
+		         GdkScreen	 *screen,
+		         guint            workspace,
+		         gpointer         user_data)
 {
-	GpmPrefs *prefs = GPM_PREFS (user_data);
-	if (command == G_UNIQUE_APP_ACTIVATE) {
+	GpmPrefs *prefs;
+
+	gpm_debug ("GtkUnique message %i", command);
+	prefs = GPM_PREFS (user_data);
+	if (command == GTK_UNIQUE_ACTIVATE) {
 		gpm_prefs_activate_window (prefs);
 	}
 }
@@ -101,8 +105,9 @@ main (int argc, char **argv)
  	GnomeProgram *program;
 	GpmPrefs *prefs = NULL;
 	GMainLoop *loop;
-#if HAVE_LIBGUNIQUEAPP
-	GUniqueApp *uniqueapp;
+#if HAVE_GTKUNIQUE
+	GtkUniqueApp *uniqueapp;
+	const gchar *startup_id = NULL;
 #endif
 
 	const GOptionEntry options[] = {
@@ -119,6 +124,15 @@ main (int argc, char **argv)
 
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
+#if HAVE_GTKUNIQUE
+	/* FIXME: We don't need to get the startup id once we can
+	 * depend on gtk+-2.12.  Until then we must get it BEFORE
+	 * gtk_init() is called, otherwise gtk_init() will clear it
+	 * and GtkUnique has to use racy workarounds.
+	 */
+	startup_id = g_getenv ("DESKTOP_STARTUP_ID");
+#endif
+
 	program = gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE,
 			    argc, argv,
 			    GNOME_PROGRAM_STANDARD_PROPERTIES,
@@ -129,23 +143,27 @@ main (int argc, char **argv)
 
 	gpm_debug_init (verbose);
 
-#if HAVE_LIBGUNIQUEAPP
-	gpm_debug ("Using libguniqueapp support.");
+#if HAVE_GTKUNIQUE
+	gpm_debug ("Using GtkUnique support.");
 
-	/* Arrr! Until we depend on gtk+2 2.12 we can't just use g_unique_app_get */
-	uniqueapp = g_unique_app_get_with_startup_id ("gnome-power-preferences",
-						      g_getenv ("DESKTOP_STARTUP_ID"));
+	/* Arrr! Until we depend on gtk+2 2.12 we can't just use gtk_unique_app_new */
+	uniqueapp = gtk_unique_app_new_with_id ("org.gnome.PowerManager.Preferences", startup_id);
 	/* check to see if the user has another prefs window open */
-	if (g_unique_app_is_running (uniqueapp)) {
+	if (gtk_unique_app_is_running (uniqueapp)) {
 		gpm_warning ("You have another instance running. "
 			     "This program will now close");
-		g_unique_app_activate (uniqueapp);
-		/* Until we depend on gtk+2 2.12, we need to do the startup
-		 * notification manually. Remove later... */
+		gtk_unique_app_activate (uniqueapp);
+
+		/* FIXME: This next line should be removed once we can depend
+		 * upon gtk+-2.12.  This causes the busy cursor and temporary
+		 * task in the tasklist to go away too soon (though that's
+		 * better than having them be stuck until the 30-second-or-so
+		 * timeout ends).
+		 */
 		gdk_notify_startup_complete ();
 	} else {
 #else
-	gpm_warning ("No libguniqueapp support. Cannot signal other instances");
+	gpm_warning ("No GtkUnique support. Cannot signal other instances");
 	/* we always assume we have no other running instance */
 	if (1) {
 #endif
@@ -156,10 +174,10 @@ main (int argc, char **argv)
 				  G_CALLBACK (gpm_prefs_help_cb), prefs);
 		g_signal_connect (prefs, "action-close",
 				  G_CALLBACK (gpm_prefs_close_cb), prefs);
-#if HAVE_LIBGUNIQUEAPP
+#if HAVE_GTKUNIQUE
 		/* Listen for messages from another instances */
 		g_signal_connect (G_OBJECT (uniqueapp), "message",
-				  G_CALLBACK (guniqueapp_command_cb), prefs);
+				  G_CALLBACK (gtkuniqueapp_command_cb), prefs);
 #endif
 		loop = g_main_loop_new (NULL, FALSE);
 		g_main_loop_run (loop);
@@ -169,7 +187,7 @@ main (int argc, char **argv)
 
 	gpm_debug_shutdown ();
 
-#if HAVE_LIBGUNIQUEAPP
+#if HAVE_GTKUNIQUE
 	g_object_unref (uniqueapp);
 #endif
 	g_object_unref (program);
