@@ -390,7 +390,7 @@ ac_adapter_changed_cb (GpmAcAdapter      *ac_adapter,
 
 	/* only do brightness changes if we have the hardware */
 	gpm_conf_get_bool (srv_backlight->priv->conf, GPM_CONF_DISPLAY_STATE_CHANGE, &do_laptop_lcd);
-	if (do_laptop_lcd) {
+	if (do_laptop_lcd == TRUE && srv_backlight->priv->can_dim == TRUE) {
 		gpm_brightness_lcd_set_std (srv_backlight->priv->brightness, value);
 	}
 }
@@ -411,16 +411,22 @@ button_pressed_cb (GpmButton        *button,
 
 	if (strcmp (type, GPM_BUTTON_BRIGHT_UP) == 0) {
 
-		gpm_brightness_lcd_up (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_up (srv_backlight->priv->brightness);
+		}
 
 	} else if (strcmp (type, GPM_BUTTON_BRIGHT_DOWN) == 0) {
 
-		gpm_brightness_lcd_down (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_down (srv_backlight->priv->brightness);
+		}
 
 	} else if (strcmp (type, GPM_BUTTON_LID_OPEN) == 0) {
 
 		/* make sure we undim when we lift the lid */
-		gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		if (srv_backlight->priv->can_dim == TRUE) {
+			gpm_brightness_lcd_undim (srv_backlight->priv->brightness);
+		}
 		gpm_srv_backlight_sync_policy (srv_backlight);	
 	}
 }
@@ -701,6 +707,9 @@ gpm_srv_backlight_init (GpmSrvBacklight *srv_backlight)
 	srv_backlight->priv->idle = gpm_idle_new ();
 	g_signal_connect (srv_backlight->priv->idle, "idle-changed",
 			  G_CALLBACK (idle_changed_cb), srv_backlight);
+
+	/* sync at startup */
+	gpm_srv_backlight_sync_policy (srv_backlight);
 }
 
 /**
